@@ -18,5 +18,17 @@ class TerraformCliError(Exception):
     pass
 
 
+class TPAexecCliError(Exception):
+    pass
+
+
 class CliError(Exception):
     pass
+
+
+class VMWareCliError(Exception):
+    pass
+
+
+class VirtualBoxCliError(Exception):
+    pass
\ No newline at end of file
